Learn R Programming

cuperdec (version 1.1.0)

calculate_curve: Calculate cumulative decay percent curve

Description

Performs the initial decay curve based on percentage of 'target' isolation source along a rank of most to least abundant taxa for a given sample.

Usage

calculate_curve(taxa_table, database)

Arguments

taxa_table

An OTU table loaded with load_taxa_table.

database

A database file loaded with load_database.

Value

An object in the form of a tibble with taxa of each given sample ordered by rank and the proportion of taxa up to that rank deriving from your target source.

Examples

Run this code
# NOT RUN {
data(cuperdec_taxatable_ex)
data(cuperdec_database_ex)

taxa_table <- load_taxa_table(cuperdec_taxatable_ex)
iso_database <- load_database(cuperdec_database_ex, target = "oral")

calculate_curve(taxa_table, iso_database)
# }

Run the code above in your browser using DataLab